==> ngp-6.x-1.1.tar.gz: ngp/page.tpl.php <==
<?php // $Id: page.tpl.php,v 1.2 2010/01/14 23:32:26 seanr Exp $ ?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
	"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">

<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php print $language->language ?>" lang="<?php print $language->language ?>">
  <head>
  	<title><?php print $head_title ?></title>
  	<meta http-equiv="content-language" content="<?php print $language->language ?>" />
  	<?php print $meta; ?>
    <?php print $head; ?>
    <?php print $styles; ?>
    <!--[if lte IE 7]>
      <link rel="stylesheet" href="<?php print $path; ?>blueprint/blueprint/ie.css" type="text/css" media="screen, projection">
    	<link href="<?php print $path; ?>fix-ie.css" rel="stylesheet"  type="text/css"  media="screen, projection" />
    <![endif]-->  
    <!--[if lte IE 6]>
    	<link href="<?php print $path; ?>fix-ie6.css" rel="stylesheet"  type="text/css"  media="screen, projection" />
    <![endif]-->  
  </head>
  <body class="<?php print $body_classes; ?>">
    <div id="background-body" class="background"><div id="background-header" class="background"><div id="background-footer" class="background">
      <div id="header" class="container">
        <?php if ($header): ?>
          <div class="blocks"><?php print $header; ?></div>
        <?php endif ?>
        <div id="logo-floater">
        <?php
          // Prepare header
          if ($site_name) $site_html = '<span class="title">'. check_plain($site_name) .'</span>';
          if ($site_slogan) $site_html .= '<span class="title">'. check_plain($site_slogan) .'</span>';

          if ($logo || $site_name) {
            print '<h1><a href="'. check_url($front_page) .'" title="'. check_plain($site_name) .'">';
            if ($logo && !theme_get_setting('default_logo')) {
              print '<img src="'. check_url($logo) .'" alt="'. check_plain($site_name) .'" id="logo" />';
            }
            print $site_html .'</a></h1>';
          }
        ?>
        </div>
      </div>
      <div class="container" id="navigation">
        <?php if (isset($primary_links)) : ?>
          <?php print theme('links', $primary_links, array('id' => 'primary', 'class' => 'links')) ?>
        <?php endif; ?>
      </div>
      <div class="container" id="content">
        <?php if ($top): ?>
          <div id="blocks-top" class="region"><?php print $top; ?></div>
        <?php endif ?>
      
        <?php if ($left): ?>
          <div id="blocks-left" class="region <?php print $left_classes; ?>"><?php print $left; ?></div>
        <?php endif ?>
        
        <div id="body" class="<?php print $center_classes; ?>">
          <?php
            if ($context_links) { 
              print '<div class="context-links">'. $context_links .'</div>';
            }
            
            if ($title != '') {
              print '<h2 class="page-title">'. $title .'</h2>';
            }
            
            if ($tabs != '') {
              print '<div class="tabs">'. $tabs .'</div>';
            }
            
            if ($messages != '') {
              print '<div id="messages">'. $messages .'</div>';
            }
            
            if ($content_top) {
              print $content_top;
            }
            
            print $help; // Drupal already wraps this one in a class      
            
            print $content;
            print $feed_icons;
            
            if ($breadcrumb != '') {
              print $breadcrumb;
            }
          ?>
        </div>
        
        <?php if ($right): ?>
          <div id="blocks-right" class="region <?php print $right_classes; ?>"><?php print $right; ?></div>
        <?php endif ?>
        
        <div class="clear"></div>
      </div>
      <div id="footer" class="container clear prepend-top append-bottom">
        <?php if (isset($secondary_links)) : ?>
          <?php print ngp_footer_links($secondary_links, array('id' => 'secondary', 'class' => 'links')) ?>
        <?php endif; ?>
        <?php if ($footer): ?>
          <?php print $footer; ?>
        <?php endif; ?>
        <?php if ($footer_message): ?>
          <div id="footer-message"><?php print $footer_message; ?></div>
        <?php endif; ?>
        <div class="clear"></div>
        <div id="poweredby"><img src="<?php print $path; ?>images/poweredbyngp.gif" alt="Powered by NGP Software" border="0" /> Powered by <a href="http://www.ngpsoftware.com">NGP Software</a>.</div>
      </div>
    </div></div></div>
    <div class="clear"></div>
    <?php print $scripts ?>
    <?php print $closure; ?>
  </body>
</html>

==> ngp-6.x-1.6.tar.gz: ngp/page.tpl.php <==
<?php // $Id: page.tpl.php,v 1.3 2010/03/24 21:35:41 seanr Exp $ ?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
	"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">

<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php print $language->language ?>" lang="<?php print $language->language ?>">
  <head>
  	<title><?php print $head_title ?></title>
  	<meta http-equiv="content-language" content="<?php print $language->language ?>" />
  	<?php print $meta; ?>
    <?php print $head; ?>
    <?php print $styles; ?>
    <!--[if lte IE 7]>
      <link rel="stylesheet" href="<?php print $path; ?>blueprint/blueprint/ie.css" type="text/css" media="screen, projection">
    	<link href="<?php print $path; ?>fix-ie.css" rel="stylesheet"  type="text/css"  media="screen, projection" />
    <![endif]-->  
    <!--[if lte IE 6]>
    	<link href="<?php print $path; ?>fix-ie6.css" rel="stylesheet"  type="text/css"  media="screen, projection" />
    <![endif]-->  
  </head>
  <body class="<?php print $body_classes; ?>">
    <div id="background-body" class="background"><div id="background-header" class="background"><div id="background-footer" class="background">
      <div id="header" class="container">
        <?php if ($header): ?>
          <div class="blocks"><?php print $header; ?></div>
        <?php endif ?>
        <div id="logo-floater">
        <?php
          // Prepare header
          if ($site_name) $site_html = '<span class="title">'. check_plain($site_name) .'</span>';
          if ($site_slogan) $site_html .= '<span class="title">'. check_plain($site_slogan) .'</span>';

          if ($logo || $site_name) {
            print '<h1><a href="'. check_url($front_page) .'" title="'. check_plain($site_name) .'">';
            if ($logo && !theme_get_setting('default_logo')) {
              print '<img src="'. check_url($logo) .'" alt="'. check_plain($site_name) .'" id="logo" />';
            }
            print $site_html .'</a></h1>';
          }
        ?>
        </div>
      </div>
      <div class="container" id="navigation">
        <?php if (isset($primary_links)) print menu_tree('primary-links'); ?>
      </div>
      <div class="container" id="content">
        <?php if ($top): ?>
          <div id="blocks-top" class="region"><?php print $top; ?></div>
        <?php endif ?>
      
        <?php if ($left): ?>
          <div id="blocks-left" class="region <?php print $left_classes; ?>"><?php print $left; ?></div>
        <?php endif ?>
        
        <div id="body" class="<?php print $center_classes; ?>">
          <?php
            if ($context_links) { 
              print '<div class="context-links">'. $context_links .'</div>';
            }
            
            if ($title != '') {
              print '<h2 class="page-title">'. $title .'</h2>';
            }
            
            if ($tabs != '') {
              print '<div class="tabs">'. $tabs .'</div>';
            }
            
            if ($messages != '') {
              print '<div id="messages">'. $messages .'</div>';
            }
            
            if ($content_top) {
              print $content_top;
            }
            
            print $help; // Drupal already wraps this one in a class      
            
            print $content;
            print $feed_icons;
            
            if ($breadcrumb != '') {
              print $breadcrumb;
            }
          ?>
        </div>
        
        <?php if ($right): ?>
          <div id="blocks-right" class="region <?php print $right_classes; ?>"><?php print $right; ?></div>
        <?php endif ?>
        
        <div class="clear"></div>
      </div>
      <div id="footer" class="container clear prepend-top append-bottom">
        <?php if (isset($secondary_links)) : ?>
          <?php print ngp_footer_links($secondary_links, array('id' => 'secondary', 'class' => 'links')) ?>
        <?php endif; ?>
        <?php if ($footer): ?>
          <?php print $footer; ?>
        <?php endif; ?>
        <?php if ($footer_message): ?>
          <div id="footer-message"><?php print $footer_message; ?></div>
        <?php endif; ?>
        <div class="clear"></div>
        <div id="poweredby"><img src="<?php print $path; ?>images/poweredbyngp.gif" alt="Powered by NGP Software" border="0" /> Powered by <a href="http://www.ngpsoftware.com">NGP Software</a>.</div>
      </div>
    </div></div></div>
    <div class="clear"></div>
    <?php print $scripts ?>
    <?php print $closure; ?>
  </body>
</html>
